@@ -10,7 +10,7 @@ from django.http import (
 from django.template.response import TemplateResponse
 
 from .constants import TURBO_STREAM_MIME_TYPE, Action
-from .renderers import BaseRenderer, render_turbo_frame, render_turbo_stream
+from .renderers import render_turbo_frame, render_turbo_stream
 
 
 class HttpResponseSeeOther(HttpResponseRedirect):
@@ -66,13 +66,10 @@ class TurboStreamResponse(TurboStreamResponseMixin, HttpResponse):
         action: Optional[Action] = None,
         target: Optional[str] = None,
         is_safe: bool = False,
-        renderer: Optional[BaseRenderer] = None,
         **response_kwargs,
     ):
         if action and target and isinstance(content, str):
-            content = render_turbo_stream(
-                action, target, content, is_safe=is_safe, renderer=renderer
-            )
+            content = render_turbo_stream(action, target, content, is_safe=is_safe)
         super().__init__(content, **response_kwargs)
 
 
@@ -97,7 +94,6 @@ class TurboStreamTemplateResponse(TurboStreamResponseMixin, TemplateResponse):
         *,
         action: Action,
         target: str,
-        renderer: Optional[BaseRenderer] = None,
         **kwargs,
     ):
 
@@ -115,7 +111,6 @@ class TurboStreamTemplateResponse(TurboStreamResponseMixin, TemplateResponse):
 
         self._target = target
         self._action = action
-        self._renderer = renderer
 
     @property
     def rendered_content(self) -> str:
@@ -123,7 +118,6 @@ class TurboStreamTemplateResponse(TurboStreamResponseMixin, TemplateResponse):
             action=self._action,
             target=self._target,
             content=super().rendered_content,
-            renderer=self._renderer,
             is_safe=True,
         )
 
@@ -137,11 +131,14 @@ class TurboFrameResponse(HttpResponse):
         *,
         dom_id: str,
         is_safe: bool = False,
-        renderer: Optional[BaseRenderer] = None,
         **response_kwargs,
     ):
         super().__init__(
-            render_turbo_frame(dom_id, content, is_safe=is_safe, renderer=renderer),
+            render_turbo_frame(
+                dom_id,
+                content,
+                is_safe=is_safe,
+            ),
             **response_kwargs,
         )
 
@@ -165,7 +162,6 @@ class TurboFrameTemplateResponse(TemplateResponse):
         context: Optional[Mapping[str, Any]] = None,
         *,
         dom_id,
-        renderer: Optional[BaseRenderer] = None,
         **kwargs,
     ):
 
@@ -177,7 +173,6 @@ class TurboFrameTemplateResponse(TemplateResponse):
         )
 
         self._dom_id = dom_id
-        self._renderer = renderer
 
     @property
     def rendered_content(self) -> str:
@@ -185,5 +180,4 @@ class TurboFrameTemplateResponse(TemplateResponse):
             self._dom_id,
             super().rendered_content,
             is_safe=True,
-            renderer=self._renderer,
         )
