@@ -13,7 +13,6 @@ from django.views.generic import (
 from . import Action
 from .mixins import (
     TurboFormMixin,
-    TurboFormModelMixin,
     TurboFrameResponseMixin,
     TurboFrameTemplateResponseMixin,
     TurboStreamFormMixin,
@@ -43,11 +42,11 @@ class TurboFormView(TurboFormMixin, FormView):
     ...
 
 
-class TurboCreateView(TurboFormModelMixin, CreateView):
+class TurboCreateView(TurboFormMixin, CreateView):
     ...
 
 
-class TurboUpdateView(TurboFormModelMixin, UpdateView):
+class TurboUpdateView(TurboFormMixin, UpdateView):
     ...
 
 
